Extensions
==========

.. automodule:: siotls.contents.handshakes.extensions
   :members:

The following modules define the concretes classes for :class:`Extension`:

.. toctree::
   :maxdepth: 1

   alpn
   certificate_authorities
   certificate_type
   cookie
   early_data
   heartbeat
   key_share
   max_fragment_length
   oid_filters
   padding
   post_handshake_auth
   pre_shared_key
   psk_key_exchange_modes
   server_name
   signature_algorithms
   signed_certificate_timestamp
   status_request
   supported_groups
   supported_versions
   use_srtp
